AWS Cloudwatch Metrics 

[![Build Status](https://travis-ci.com/random1st/cloudwatch-metrics.svg?branch=master)](https://travis-ci.com/random1st/cloudwatch-metrics)
[![PyPI version](https://badge.fury.io/py/cloudwatch-metrics.svg)](https://badge.fury.io/py/cloudwatch-metrics)